List the available study files in Harvard Dataverse. Call this without arguments to see the filenames and notes you can pass to load_data().
Usage
view_data(name_type = NULL, name_target = NULL)
Arguments
- name_type
Leave NULL. This version returns metadata only when both filter arguments are NULL.
- name_target
Leave NULL. This version does not implement filtering by target.
Value
A data frame with filename, type and notes columns; NULL if either filter argument is supplied.